@@ -179,6 +179,40 @@ def test_get_apps_data(marathon_site, user, password, params, exception):
 # def deploy_apps(test, marathon_site, user, password, job_list):
 
 
+@pytest.mark.parametrize(
+    "json_data, remove_keys, present_keys",
+    [
+        (
+            [
+                {
+                    "id": "/myproject/myapp",
+                    "cmd": "null",
+                    "args": "null",
+                    "fetch": [],
+                    "version": "2020-07-06T11:48:15.148Z",
+                    "versionInfo": {
+                        "lastScalingAt": "2020-07-06T11:48:15.148Z",
+                        "lastConfigChangeAt": "2020-06-30T12:10:39.942Z",
+                    },
+                }
+            ],
+            ("version", "versionInfo", "fetch"),
+            ("id", "cmd", "args"),
+        ),
+    ],
+)
+def test_remove_fields(json_data, remove_keys, present_keys):
+    """Validate correct fields are removed."""
+    job_list = __main__.remove_fields(json_data, remove_keys)
+    print(f"> job_list is: {job_list}")
+
+    for field in remove_keys:
+        assert field not in job_list[0]
+
+    for field in present_keys:
+        assert field in job_list[0]
+
+
 @pytest.mark.parametrize(
     "json_data", [([{"id": "/myproject/myapp", "cmd": "null", "args": "null"}]),],
 )
